# savvi

savvi is a package for Safe Anytime Valid Inference. Also, it’s a savvy
pun.

Read the [docs](https://assuncaolfi.github.io/savvi/) for more.

## Install

Stable version:

```shell
pip install savvi
```

Development version:

```shell
pip install git+https://github.com/assuncaolfi/savvi
```

For development, use [pdm](https://github.com/pdm-project/pdm).

## Get started

See the [example gallery](https://assuncaolfi.github.io/savvi/examples/).
